<div class="field">
  <div class="file is-primary has-name">
    <label class="file-label">
      <input type="file" name="{{ widget.checkbox_name }}"{% include "django/forms/widgets/attrs.html" %}>
      <span class="file-cta">
        <span class="file-icon">
          <i class="fas fa-upload"></i>
        </span>
        <span class="file-label">
          Upload file
        </span>
      </span>
      <span class="file-name">
          ...
      </span>
    </label>
  </div>
</div>
